@@ -1,4 +1,4 @@
-# Copyright (C) 2016-2020 Damon Lynch <damonlynch@gmail.com>
+# Copyright (C) 2016-2022 Damon Lynch <damonlynch@gmail.com>
 
 # This file is part of Rapid Photo Downloader.
 #
@@ -20,19 +20,27 @@
 # https://github.com/pypa/readme_renderer/blob/master/readme_renderer/__about__.py
 
 __all__ = [
-    '__title__', '__summary__', '__uri__', '__version__', '__author__',
-    '__email__', '__license__', '__copyright__',
+    "__title__",
+    "__summary__",
+    "__uri__",
+    "__version__",
+    "__author__",
+    "__email__",
+    "__license__",
+    "__copyright__",
 ]
 
-__title__ = 'rapid-photo-downloader'
-__summary__ = 'Downloads, renames and backs up photos and videos from cameras, phones, ' \
-'memory cards and other devices'
-__uri__ = 'http://www.damonlynch.net/rapid'
+__title__ = "rapid-photo-downloader"
+__summary__ = (
+    "Downloads, renames and backs up photos and videos from cameras, phones, "
+    "memory cards and other devices"
+)
+__uri__ = "https://damonlynch.net/rapid"
 
-__version__ = '0.9.26'
+__version__ = "0.9.34"
 
-__author__ = 'Damon Lynch'
-__email__ = 'damonlynch@gmail.com'
+__author__ = "Damon Lynch"
+__email__ = "damonlynch@gmail.com"
 
-__license__ = 'GPL 3+'
-__copyright__ = 'Copyright 2007-2020 {}'.format(__author__)
+__license__ = "GPL 3+"
+__copyright__ = "Copyright 2007-2022 {}".format(__author__)
